package com.xkrs.common.schedule;

import com.fasterxml.jackson.databind.JsonNode;
import com.xkrs.dao.WeatherDao;
import com.xkrs.model.entity.Weather;
import com.xkrs.util.WeatherUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.time.LocalDateTime;


/**
 * 定时任务
 * @author tajochen
 */
@Configuration
@EnableScheduling
public class SaticScheduleTask {

    Logger logger = LoggerFactory.getLogger(SaticScheduleTask.class);

    @Resource
    private WeatherDao weatherDao;


    /**
     * 每天零点入库天气信息
     */
    @Scheduled(cron = "0 0 0 * * ?")
    private void configureTasks() {
        logger.info("执行静态定时任务时间: " + LocalDateTime.now());
        System.out.println("------" + "开始执行定时任务");
        JsonNode forecastWeather = WeatherUtils.getForecastWeather();
        JsonNode results = forecastWeather.path("results");
        JsonNode jsonNode = results.get(0);
        JsonNode daily = jsonNode.path("daily");
        JsonNode jsonNode1 = daily.get(0);
        Weather weather = new Weather();
        weather.setWindSpeed(jsonNode1.get("wind_speed").asText());
        weather.setWindDirection(jsonNode1.get("wind_direction").asText());
        weather.setHighTemperature(jsonNode1.get("high").asText());
        weather.setLowTemperature(jsonNode1.get("low").asText());
        weather.setHumidity(jsonNode1.get("humidity").asText());
        weather.setRainfall(jsonNode1.get("rainfall").asText());
        weather.setWeatherDay(jsonNode1.get("text_day").asText());
        weather.setWeatherNight(jsonNode1.get("text_night").asText());
        weather.setWeatherTime(jsonNode1.get("date").asText());
        weatherDao.save(weather);
    }

}
