package com.xkrs.util;

/**
 * @Author: XinYi Song
 * @Date: 2022/2/8 14:42
 */
import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xkrs.dao.FireDao;
import com.xkrs.model.entity.Fire;
import com.xkrs.websocket.server.WebSocketServer;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.jms.annotation.JmsListener;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

@Component
public class TopicConsumerListener {

    @Resource
    private FireDao fireDao;

    /**
     * topic模式的消费者
     * 订阅火情报警信息
     * @param message
     */
    @CacheEvict(value = "FireServiceCache",allEntries = true)
    @JmsListener(destination="${spring.activemq.topic-name}", containerFactory="topicListener")
    public void readActiveQueue(String message) throws IOException {
        ObjectMapper objectMapper = new ObjectMapper();
        JsonNode jsonNode = objectMapper.readTree(message);
        String method = jsonNode.get("method").asText();
        if("vms.alarm.msg".equals(method)){
            JsonNode info = jsonNode.get("info");
            Fire fire = new Fire();
            fire.setDeviceCode(info.get("deviceCode").asText());
            fire.setChannelSeq(info.get("channelSeq").asText());
            fire.setUnitType(info.get("unitType").asText());
            fire.setNodeType(info.get("nodeType").asText());
            fire.setNodeCode(info.get("nodeCode").asText());
            String alarmCode = info.get("alarmCode").asText();
            fire.setAlarmCode(alarmCode);
            fire.setAlarmStat(info.get("alarmStat").asText());
            fire.setAlarmType(info.get("alarmType").asText());
            fire.setAlarmGrade(info.get("alarmGrade").asText());
            fire.setAlarmPicture(info.get("alarmPicture").asText());
            String modifyTime = DateTimeUtil.timeMillisToString(Long.parseLong(info.get("alarmDate").asText()));
            fire.setAlarmDate(modifyTime);
            fire.setAlarmSourceName(info.get("alarmSourceName").asText());
            fire.setAlarmLongitude(info.get("gpsX").asText());
            fire.setAlarmLatitude(info.get("gpsY").asText());
            fire.setAltitude(info.get("altitude").asText());
            fire.setFireDistance(info.get("fireDistance").asText());
            fire.setFireId(info.get("fsid").asText());
            fire.setFireState("0");
            Map<String,String> map = new HashMap<String,String>();
            map.put("deviceCode",info.get("deviceCode").asText());
            map.put("channelSeq",info.get("channelSeq").asText());
            map.put("unitType",info.get("unitType").asText());
            map.put("nodeType",info.get("nodeType").asText());
            map.put("nodeCode",info.get("nodeCode").asText());
            map.put("alarmCode",alarmCode);
            map.put("alarmStat",info.get("alarmStat").asText());
            map.put("alarmType",info.get("alarmType").asText());
            map.put("alarmGrade",info.get("alarmGrade").asText());
            map.put("alarmPicture",info.get("alarmPicture").asText());
            map.put("alarmDate",modifyTime);
            map.put("alarmSourceName",info.get("alarmSourceName").asText());
            map.put("alarmLongitude",info.get("gpsX").asText());
            map.put("alarmLatitude",info.get("gpsY").asText());
            map.put("altitude",info.get("altitude").asText());
            map.put("fireDistance",info.get("fireDistance").asText());
            map.put("fsid",info.get("fsid").asText());
            map.put("fireState","0");
            String jsonString = JSON.toJSONString(map);
            WebSocketServer.BroadCastInfo(jsonString);

            fireDao.save(fire);
        }
    }

    /**
     * 订阅火情图片
     * @param message
     */
    @Transactional(rollbackOn = Exception.class)
    @JmsListener(destination="${spring.activemq.topic-name1}", containerFactory="topicListener")
    public void readActivePicture(String message) throws JsonProcessingException {
        ObjectMapper objectMapper = new ObjectMapper();
        JsonNode jsonNode = objectMapper.readTree(message);
        String method = jsonNode.get("method").asText();
        if("vms.notifyAlarmPicture".equals(method)){
            JsonNode info = jsonNode.get("info");
            String alarmCode = info.get("alarmCode").asText();
            Fire byAlarmCode = fireDao.findByAlarmCode(alarmCode);
            if("".equals(byAlarmCode.getPicturePath()) || byAlarmCode.getPicturePath() == null){
                String picture = info.get("picture").asText();
                fireDao.updatePicturePath(alarmCode,picture);
            }else {
                String picture1 = byAlarmCode.getPicturePath() + "," + info.get("picture").asText();
                fireDao.updatePicturePath(alarmCode,picture1);
            }

            System.out.println("topic接受到的图片：" + message);
        }
    }


}
